@@ -1,13 +1,13 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##      @(#) mhopt.pl 2.8 98/11/08 11:55:42
+##      @(#) mhopt.pl 2.13 99/06/25 23:06:25
 ##  Author:
-##      Earl Hood       earlhood@usa.net
+##      Earl Hood       mhonarc@pobox.com
 ##  Description:
 ##      Routines to set options for MHonArc.
 ##---------------------------------------------------------------------------##
 ##    MHonArc -- Internet mail-to-HTML converter
-##    Copyright (C) 1997-1998	Earl Hood, earlhood@usa.net
+##    Copyright (C) 1997-1999	Earl Hood, mhonarc@pobox.com
 ##
 ##    This program is free software; you can redistribute it and/or modify
 ##    it under the terms of the GNU General Public License as published by
@@ -27,7 +27,10 @@
 
 package mhonarc;
 
+no strict;
+
 use Getopt::Long;
+use Time::Local;
 
 ##---------------------------------------------------------------------------
 ##	get_resources() is responsible for grabbing resource settings from
@@ -42,10 +45,14 @@ sub get_resources {
     GetOptions(\%opt,
 	"add",		# Add a message to archive
 	"afs",		# Bypass file permission checks
+	"addressmodifycode=s",
+			# Perl expression for modifying displayed addresses
 	"annotate",	# Add a note to message(s)
 	"authsort",	# Sort by author
 	"archive",	# Create an archive (the default)
 	"conlen",	# Honor Content-Length fields
+	"checknoarchive",
+			# Check for "no archive" flag in messages
 	"datefields=s", # Fields that contains the date of a message
 	"dbfile=s",	# Database/state filename for mhonarc archive
 	"decodeheads",	# Decode all 1522 encoded data in message headers
@@ -74,6 +81,7 @@ sub get_resources {
 			# Date specification for local date
 	"lock",		# Do archive locking (default)
 	"lockdelay=i",	# Time delay in seconds between lock tries
+	"lockmethod=s",	# Set the method of locking
 	"locktries=i",	# Number of tries in locking an archive
 	"mailtourl=s",	# URL to use for e-mail address hyperlinks
 	"main",		# Create a main index
@@ -91,6 +99,8 @@ sub get_resources {
 	"news",		# Add links to newsgroups
 	"noauthsort",	# Do not sort by author
 	"noarchive",	# Do not create an archive
+	"nochecknoarchive",
+			# Do not check for "no archive" flag in messages
 	"noconlen",	# Ignore Content-Length fields
 	"nodecodeheads",
 			# Do not decode 1522 encoded data in message headers
@@ -107,7 +117,10 @@ sub get_resources {
 	"nonews",	# Do not add links to newsgroups
 	"noreverse",	# List messages in normal order
 	"nosort",	# Do not sort
+	"nospammode",	# Do not run in (anti)spam mode
 	"nosubsort",	# Do not sort by subject
+	"nosubjectthreads",
+			# Do not do subject based threading
 	"notedir",	# Location of notes
 	"notetext=s@",	# Text data of note
 	"nothread",	# Do not create threaded index
@@ -126,12 +139,17 @@ sub get_resources {
 	"scan",		# List out archive contents to terminal
 	"single",	# Convert a single message to HTML
 	"sort",		# Sort messages in increasing date order
+	"spammode",	# Run in (anti)spam mode
+	"stderr=s",	# Set file for stderr
+	"stdout=s",	# Set file for stdout
 	"subjectarticlerxp=s",
 			# Regex for leading articles in subjects
 	"subjectreplyrxp=s",
 			# Regex for leading reply string in subjects
 	"subjectstripcode=s",
 			# Perl expression for modifying subjects
+	"subjectthreads",
+			# Check subjects for threads
 	"subsort",	# Sort message by subject
 	"tidxfname=s",	# File name of threaded index page
 	"tidxprefix=s",	# Filename prefix for multi-page thread index
@@ -164,9 +182,26 @@ sub get_resources {
     if ($opt{'help'}) 	{ &usage();   return 0; }
     if ($opt{'v'}) 	{ &version(); return 0; }
 
+    ## Check if stdout & stderr should go to files
+    DUP: {
+	if (defined($opt{'stdout'})) {
+	    open(STDOUT, ">>$opt{'stdout'}") ||
+		die qq/ERROR: Unable to create "$opt{'stdout'}": $!\n/;
+	    if ($opt{'stderr'} eq $opt{'stdout'}) {
+		open(STDERR, ">&STDOUT") ||
+		    die qq/ERROR: Unable to dup STDOUT: $!\n/;
+	    }
+	}
+	if (defined($opt{'stderr'})) {
+	    open(STDERR, ">>$opt{'stderr'}") ||
+		die qq/ERROR: Unable to create "$opt{'stderr'}": $!\n/;
+	}
+	select(STDOUT); $| = 1;
+	select(STDERR); $| = 1;
+    }
+
     ## Initialize variables
-    require 'mhinit.pl'    || die("ERROR: Unable to require mhinit.pl\n");
-    &mhinit_vars();
+    require 'mhinit.pl';   &mhinit_vars();
 
     ## These options have NO resource file equivalent.
     $NoArg   = $opt{'noarg'};
@@ -203,25 +238,33 @@ sub get_resources {
     }
 
     ## Require needed libraries
-    require 'timelocal.pl' || die("ERROR: Unable to require timelocal.pl\n");
-    require 'ewhutil.pl'   || die("ERROR: Unable to require ewhutil.pl\n");
-    require 'mhtime.pl'    || die("ERROR: Unable to require mhtime.pl\n");
-    require 'mhfile.pl'    || die("ERROR: Unable to require mhfile.pl\n");
-    require 'mhutil.pl'    || die("ERROR: Unable to require mhutil.pl\n");
-    require 'mhscan.pl'    || die("ERROR: Unable to require mhscan.pl\n")
-	if $SCAN;
-    require 'mhsingle.pl'  || die("ERROR: Unable to require mhsingle.pl\n")
-	if $SINGLE;
-    require 'mhrmm.pl'     || die("ERROR: Unable to require mhrmm.pl\n")
-	if $RMM;
-    require 'mhnote.pl'    || die("ERROR: Unable to require mhnote.pl\n")
-	if $ANNOTATE;
+    require 'ewhutil.pl';
+    require 'mhtime.pl';
+    require 'mhfile.pl';
+    require 'mhutil.pl';
+    require 'mhscan.pl'  	if $SCAN;
+    require 'mhsingle.pl'  	if $SINGLE;
+    require 'mhrmm.pl'  	if $RMM;
+    require 'mhnote.pl'  	if $ANNOTATE;
 
+    ## Evaluate site local initialization
+    delete($INC{'mhasiteinit.pl'});      # force re-evaluation
+    eval { require 'mhasiteinit.pl'; };  # ignore status
+
+    ## Read default resource file
     if ($DefRcFile) {
 	&read_fmt_file($DefRcFile);
     } else {
 	$tmp = join($DIRSEP, $ENV{'HOME'}, $DefRcName);
-	$tmp = join($DIRSEP, $INC[0], $DefRcName)  unless (-e $tmp);
+	if (! -e $tmp) {
+	    local $_;
+	    foreach (@INC) {
+		if (-e join($DIRSEP, $_, 'mhamain.pl')) {
+		    $tmp = join($DIRSEP, $_, $DefRcName);
+		    last;
+		}
+	    }
+	}
 	if (-e $tmp) {
 	    &read_fmt_file($tmp);
 	}
@@ -235,10 +278,13 @@ sub get_resources {
 					($opt{'lockdelay'} > 0);
     $FORCELOCK = $opt{'force'};
 
+    $LockMethod = &set_lock_mode($opt{'lockmethod'})
+		  if defined($opt{'lockmethod'});
+
     ## These options must be grabbed before reading the database file
     ## since these options may tells us where the database file is.
     $OUTDIR  = $opt{'outdir'}    if $opt{'outdir'};
-    if (!$NoArg && !($SCAN || $IDXONLY)) {
+    if (!$NoArg && !($SCAN || $IDXONLY || $SINGLE)) {
 	die qq/ERROR: "$OUTDIR" does not exist\n/    unless -e $OUTDIR;
 	if (!$AFS) {
 	    die qq/ERROR: "$OUTDIR" is not readable\n/   unless -r $OUTDIR;
@@ -248,20 +294,12 @@ sub get_resources {
     }
     $DBFILE  = $opt{'dbfile'}    if $opt{'dbfile'};
 
-    ## Create lockfile
-    &set_handler();
+    ## Create lock
     $LOCKFILE  = join($DIRSEP, $OUTDIR, $LOCKFILE);
-    if ($dolock && $DoArchive && !$SINGLE &&
-	!&create_lock_file($LOCKFILE, 1, 0, 0)) {
-
-	print STDOUT qq/Trying to lock mail archive in "$OUTDIR" ...\n/
-	    unless $QUIET;
-	if (!&create_lock_file($LOCKFILE,
-			       $LOCKTRIES-1,
-			       $LOCKDELAY,
-			       $FORCELOCK)) {
+    if ($dolock && $DoArchive && !$SINGLE) {
+	if (!&$LockFunc($LOCKFILE, $LOCKTRIES, $LOCKDELAY, $FORCELOCK)) {
 	    $! = 75; # EX_TEMPFAIL (for sendmail)
-	    die("ERROR: Unable to create $LOCKFILE after $LOCKTRIES tries\n");
+	    die("ERROR: Unable to lock $OUTDIR after $LOCKTRIES tries\n");
 	}
     }
 
@@ -305,11 +343,14 @@ sub get_resources {
     }
     my($OldMULTIIDX) = $MULTIIDX;
 
-    ## Remove lock file if db not going to be changed
+    ## Remove lock if db not going to be changed
     if ($SCAN || $IDXONLY) {
-	&remove_lock_file();
+	&$UnlockFunc();
     }
 
+    ## Clear thread flag if genidx, must be explicitly set
+    $THREAD = 0  if $IDXONLY;
+
     ##	Read resource file(s) (I initially used the term 'format file').
     ##	Look for resource in outdir unless existing according to
     ##  current value.
@@ -390,9 +431,10 @@ sub get_resources {
     $GMTDateFmt	= $opt{'gmtdatefmt'}  	  if $opt{'gmtdatefmt'};
     $LocalDateFmt = $opt{'localdatefmt'}  if $opt{'localdatefmt'};
 
-    $SubArtRxp   = $opt{'subjectarticlerxp'}  if $opt{'subjectarticlerxp'};
-    $SubReplyRxp = $opt{'subjectreplyrxp'}    if $opt{'subjectreplyrxp'};
-    $SubStripCode = $opt{'subjectstripcode'}  if $opt{'subjectstripcode'};
+    $AddressModify = $opt{'addressmodifycode'}  if $opt{'addressmodifycode'};
+    $SubArtRxp     = $opt{'subjectarticlerxp'}  if $opt{'subjectarticlerxp'};
+    $SubReplyRxp   = $opt{'subjectreplyrxp'}    if $opt{'subjectreplyrxp'};
+    $SubStripCode  = $opt{'subjectstripcode'}   if $opt{'subjectstripcode'};
 
     $IdxPageNum  = $opt{'pagenum'}   if defined($opt{'pagenum'});
 
@@ -443,11 +485,19 @@ sub get_resources {
     $GzipLinks	= 0  if $opt{'nogziplinks'};
     $NoMsgPgs	= 0  if $opt{'msgpgs'};
     $NoMsgPgs	= 1  if $opt{'nomsgpgs'};
+    $SpamMode	= 1  if $opt{'spammode'};
+    $SpamMode	= 0  if $opt{'nospammode'};
+
+    $CheckNoArchive = 1 if $opt{'checknoarchive'};
+    $CheckNoArchive = 0 if $opt{'nochecknoarchive'};
 
     $DecodeHeads = 1 if $opt{'decodeheads'};
     $DecodeHeads = 0 if $opt{'nodecodeheads'};
 	$readmail::DecodeHeader = $DecodeHeads;
 
+    ## Clear main flag if genidx and thread specified
+    $MAIN = 0  if $IDXONLY && $THREAD;
+
     @DateFields	 = split(/:/, $opt{'datefields'})  if $opt{'datefields'};
     foreach (@DateFields) { s/\s//g; tr/A-Z/a-z/; }
     @FromFields	 = split(/:/, $opt{'fromfields'})  if $opt{'fromfields'};
@@ -494,6 +544,8 @@ sub get_resources {
     if ($TNOSORT) {
 	$TSUBSORT = 0;
     }
+    $NoSubjectThreads  = 1  if $opt{'nosubjectthreads'};
+    $NoSubjectThreads  = 0  if $opt{'subjectthreads'};
 
     ## Check if all messages must be updated (this has been simplified;
     ## any serious change should be done via editidx).
@@ -506,18 +558,18 @@ sub get_resources {
     ## Set date names
     &set_date_names(*weekdays, *Weekdays, *months, *Months);
 
+    ## Set %Zone with user-specified timezones
+    while (($zone, $offset) = each(%ZoneUD)) {
+	$Zone{$zone} = $offset;
+    }
+
     ## Require some more libaries
-    require 'mhidxrc.pl'  || die("ERROR: Unable to require mhidxrc.pl\n");
-    &mhidxrc_set_vars();
-
-    require 'mhdysub.pl'  || die("ERROR: Unable to require mhdysub.pl\n");
-    &create_routines();
-
-    require 'mhrcvars.pl' || die("ERROR: Unable to require mhrcvars.pl\n");
-    require 'mhindex.pl'  || die("ERROR: Unable to require mhindex.pl\n");
-    require 'mhthread.pl' || die("ERROR: Unable to require mhthread.pl\n");
-    require 'mhdb.pl'     || die("ERROR: Unable to require mhdb.pl\n")
-	unless $SCAN || $IDXONLY || !$DoArchive;
+    require 'mhidxrc.pl';   &mhidxrc_set_vars();
+    require 'mhdysub.pl';   &create_routines();
+    require 'mhrcvars.pl';
+    require 'mhindex.pl';
+    require 'mhthread.pl';
+    require 'mhdb.pl'	    unless $SCAN || $IDXONLY || !$DoArchive;
 
     ## Predefine %Index2TLoc in case of message deletion
     if (@TListOrder) {
@@ -574,61 +626,16 @@ sub version {
 ##	Usage routine
 ##
 sub usage {
-    require 'mhusage.pl' ||
-	die("ERROR: Unable to require mhusage.pl.\n",
-	    "Did you install MHonArc properly?\n");
+    require 'mhusage.pl';
     &mhusage();
 }
 
-##---------------------------------------------------------------------------
-##	create_lock_file() creates a directory to act as a lock.
-##
-sub create_lock_file {
-    my($file, $tries, $sleep, $force) = @_;
-    my($umask, $ret);
-    $ret = 0;
-    while ($tries > 0) {
-	if (mkdir($file, 0777)) {
-	    $ISLOCK = 1;
-	    $ret = 1;
-	    last;
-	}
-	sleep($sleep)  if $sleep > 0;
-	$tries--;
-    }
-    if ($force) {
-	$ISLOCK = 1;  $ret = 1;
-    }
-    $ret;
-}
-
-##---------------------------------------------------------------------------
-##	remove_lock_file removes the lock on the archive
-##
-sub remove_lock_file {
-    if ($ISLOCK) {
-	if (-d $LOCKFILE) {
-	    if (!rmdir($LOCKFILE)) {
-		warn "Warning: Unable to remove $LOCKFILE: $!\n";
-		return 0;
-	    }
-	} else {
-	    if (!unlink($LOCKFILE)) {
-		warn "Warning: Unable to remove $LOCKFILE\n";
-		return 0;
-	    }
-	}
-	$ISLOCK = 0;
-    }
-    1;
-}
-
 ##---------------------------------------------------------------------------
 ##	read_fmt_file() requires the library with the resource file
 ##	read subroutine and calls the routine.
 ##
 sub read_fmt_file {
-    require 'mhrcfile.pl' || die("ERROR: Unable to require mhrcfile.pl\n");
+    require 'mhrcfile.pl';
     &read_resource_file($_[0]);
 }
 
