@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhtxthtml.pl 2.6 98/10/25 13:58:15
+##	@(#) mhtxthtml.pl 2.7 99/03/30 21:02:47
 ##  Author:
 ##      Earl Hood       earlhood@usa.net
 ##  Description:
@@ -32,23 +32,34 @@
 
 package m2h_text_html;
 
-$Url	= '(\w+://|\w+:)';	# Beginning of URL match expression
+# Beginning of URL match expression
+my $Url	= '(\w+://|\w+:)';
+# Script related attributes
+my $SAttr = q/(?:onload|onunload|onclick|ondblclick|/.
+	    q/onmouse(?:down|up|over|move|out)|/.
+	    q/onkey(?:press|down|up))/;
 
 ##---------------------------------------------------------------------------
 ##	The filter must modify HTML content parts for merging into the
 ##	final filtered HTML messages.  Modification is needed so the
 ##	resulting filtered message is valid HTML.
 ##
+##	Arguments:
+##
+##	noscript	Remove any markup associated with scripting.
+##			This includes elements and attributes related
+##			to scripting.
+##
 sub filter {
     local($header, *fields, *data, $isdecode, $args) = @_;
-    local($base, $title, $tmp);
-    local(@files) = ();	# !!!Used by resolve_cid
-    $base 	= '';
-    $title	= '';
-    $tmp	= '';
+    local(@files) = ();	# !!!Used by resolve_cid!!!
+    my $base 	 = '';
+    my $title	 = '';
+    my $noscript = $args =~ /\bnoscript\b/i;
+    my $tmp;
 
     ## Get/remove title
-    if ($data =~ s%<title\s*>([^<]*)</title\s*>%%i) {
+    if ($data =~ s|<title\s*>([^<]*)</title\s*>||io) {
         $title = "<ADDRESS>Title: <STRONG>$1</STRONG></ADDRESS>\n";
     }
     ## Get/remove BASE url
@@ -69,22 +80,77 @@ sub filter {
     }
     $base =~ s|(.*/).*|$1|;
 
-    ## Strip out certain elements/tags
-    $data =~ s|<!doctype\s[^>]*>||i;
-    $data =~ s|</?html[^>]*>||ig;
+    ## Strip out certain elements/tags to support proper inclusion
+    $data =~ s|<!doctype\s[^>]*>||io;
+    $data =~ s|</?html[^>]*>||gio;
+    $data =~ s|<head\s*>[\s\S]*</head\s*>||io;
+
+    ## Strip out scripting markup if requested
+    if ($noscript) {
+	$data =~ s|<script[^>]*>.*?</script\s*>||gios;
+	$data =~ s|\b$SAttr\b\s*=\s*"[^"]*"||gio;
+	$data =~ s|\b$SAttr\b\s*=\s*'[^']*'||gio;
+	$data =~ s|\b$SAttr\b\s*=\s*[^\s>]+||gio;
+	$data =~ s|</?applet[^>]*>||gio;
+	$data =~ s|</?param[^>]*>||gio;
+    }
+
+    ## Check for body attributes
+    if ($data =~ s|<body\b([^>]*)>||i) {
+	require 'mhutil.pl';
+	my $a = $1;
+	my %attr = mhonarc::parse_vardef_str($a, 1);
+	if (%attr) {
+	    ## Use a table with a single cell to encapsulate data to
+	    ## set visual properties.  We use a mixture of old attributes
+	    ## and CSS to set properties since browsers may not support
+	    ## all of the CSS settings via the STYLE attribute.
+	    my $tpre = '<TABLE><TR><TD ';
+	    my $tsuf = "";
+	    $tpre .= qq|BACKGROUND="$attr{'background'}" |
+		     if $attr{'background'};
+	    $tpre .= qq|BGCOLOR="$attr{'bgcolor'}" |
+		     if $attr{'bgcolor'};
+	    $tpre .= qq|STYLE="|;
+	    $tpre .= qq|background-color: $attr{'bgcolor'}; |
+		     if $attr{'bgcolor'};
+	    if ($attr{'background'}) {
+		if ($attr{'background'} =~ s/^cid://i) {
+		    $attr{'background'} = &resolve_cid($attr{'background'});
+		} else {
+		    $attr{'background'} = &addbase($base, $attr{'background'});
+		}
+		$tpre .= qq|background-image: url($attr{'background'}) |;
+	    }
+	    $tpre .= qq|color: $attr{'text'}; |
+		     if $attr{'text'};
+	    $tpre .= qq|A:link { color: $attr{'link'} } |
+		     if $attr{'link'};
+	    $tpre .= qq|A:active { color: $attr{'alink'} } |
+		     if $attr{'alink'};
+	    $tpre .= qq|A:visited { color: $attr{'vlink'} } |
+		     if $attr{'vlink'};
+	    $tpre .= '">';
+	    if ($attr{'text'}) {
+		$tpre .= qq|<FONT COLOR="$attr{'text'}">|;
+		$tsuf .= '</FONT>';
+	    }
+	    $tsuf .= '</TD></TR></TABLE>';
+	    $data = $tpre . $data . $tsuf;
+	}
+    }
     $data =~ s|</?body[^>]*>||ig;
-    $data =~ s|<head\s*>[\s\S]*</head\s*>||i;
 
     ## Modify relative urls to absolute using BASE
     if ($base =~ /\S/) {
-        $data =~ s/((?:href|src)\s*=\s*['"])([^'"]+)(['"])/
+        $data =~ s/((?:href|src|background)\s*=\s*['"])([^'"]+)(['"])/
 		   join("", $1, &addbase($base,$2), $3)/geix;
     }
 
     ## Check for CID URLs (multipart/related HTML)
-    $data =~ s/((?:href|src)\s*=\s*['"])cid:([^'"]+)(['"])/
+    $data =~ s/((?:href|src|background)\s*=\s*['"])cid:([^'"]+)(['"])/
 	       join("", $1, &resolve_cid($2), $3)/geix;
-    $data =~ s/((?:href|src)\s*=\s*)cid:([^\s>]+)/
+    $data =~ s/((?:href|src|background)\s*=\s*)cid:([^\s>]+)/
 	       join("", $1, '"', &resolve_cid($2), '"')/geix;
 
     ($title.$data, @files);
